@@ -38,7 +38,7 @@ import sys
 
 from mopytools.util import (run, envname, update_cmd, step,
                             get_project_name, is_meta_project,
-                            has_changes)
+                            has_changes, is_git)
 
 
 @step('Updating the repo')
@@ -50,6 +50,9 @@ def updating_repo(name, channel, specific_tags, force=False, timeout=60,
               'changes will be discarded.')
         sys.exit(0)
 
+    if is_git():
+        run('git submodule update')
+
     run(update_cmd(name, channel, specific_tags, force), timeout, verbose)
 
 
